@@ -47,10 +47,14 @@ class GNCSocketServer(GNCSocketBase):
                         await asyncio.sleep(0.1)
                         # task reade
                     except asyncio.TimeoutError as te:
+                        gs.report("socket_task","Tiempo fuera en escritura %s, mode %s" %(
+                            te, gs.mode) )
                         gs.logger.exception("Tiempo fuera en escritura %s, mode %s" %(
                             te, gs.mode))
                         await asyncio.sleep(10)
                     except (ConnectionResetError, ConnectionAbortedError) as conn_error:
+                        gs.report("socket_task","Excepción por desconexión %s, mode %s"%(
+                            conn_error, gs.mode))
                         gs.logger.exception("Excepción por desconexión %s, mode %s"%(
                             conn_error, gs.mode))
                         await asyncio.sleep(10)                                                                                               
@@ -93,11 +97,12 @@ class GNCSocketServer(GNCSocketBase):
                 else:
                     loop.run_until_complete(future)
             except KeyboardInterrupt as k:
-                print("Closing with keyboard")
+                gs.report("socket_task","Closing with keyboard")
                 gs.logger.exception("Cierre forzado desde teclado %s" %ex)                
                 loop.run_until_complete(gs.wait_closed())
                 raise k
             except Exception as ex:
+                gs.report("socket_task", "Exception", ex)
                 gs.logger.exception("Error con modulo cliente gnsocket %s" %ex)                                
                 print("Otra exception", ex)
 
